Prompts
=================================


Submodules
----------

.. toctree::
   :maxdepth: 2

   genai.prompt.quickstart
   genai.prompt.quickstart.basics
   genai.prompt.quickstart.annexe
   genai.prompt.prompt_pattern.rst
